%matrix_transform
% Returns elements of a 2 x 2 transformation matrix based upon a string input.
% NOTE: this list must correspond exactly to the list defined in
% mtrans2D_defaults.m

function [a,b,c,d,...
    a_str,b_str,c_str,d_str,...
    tx1,ty1,tx2,ty2] = matrix_transform( transform_str, x, y, k, theta )

if strcmp( transform_str, 'Identity' )
    a = 1;
    b = 0;
    c = 0;
    d = 1;
    a_str = '1';
    b_str = '0';
    c_str = '0';
    d_str = '1';
    tx1 = 0;
    ty1 = 0;
    tx2 = 0;
    ty2 = 0;
elseif strcmp( transform_str, 'Enlargement SF 2 about (0,0)' )
    a = 2;
    b = 0;
    c = 0;
    d = 2;
    a_str = '2';
    b_str = '0';
    c_str = '0';
    d_str = '2';
    tx1 = 0;
    ty1 = 0;
    tx2 = 0;
    ty2 = 0;
elseif strcmp( transform_str, 'Enlargement SF 2 about object centre' )
    a = 2;
    b = 0;
    c = 0;
    d = 2;
    a_str = '2';
    b_str = '0';
    c_str = '0';
    d_str = '2';
    tx1 = mean(x);
    ty1 = mean(y);
    tx2 = mean(x);
    ty2 = mean(y);
elseif strcmp( transform_str, 'Enlargement SF 2 about (1,-1)' )
    a = 2;
    b = 0;
    c = 0;
    d = 2;
    a_str = '2';
    b_str = '0';
    c_str = '0';
    d_str = '2';
    tx1 = 1;
    ty1 = -1;
    tx2 = 1;
    ty2 = -1;
elseif strcmp( transform_str, 'Shear in x angle 30 deg about (0,0)' )
    a = 1;
    b = tan(30*pi/180);
    c = 0;
    d = 1;
    a_str = '1';
    b_str = 'tan(30)';
    c_str = '0';
    d_str = '1';
    tx1 = 0;
    ty1 = 0;
    tx2 = 0;
    ty2 = 0;
elseif strcmp( transform_str, 'Shear in -y angle 30 deg about (0,0)' )
    a = 1;
    b = 0;
    c = -tan(30*pi/180);
    d = 1;
    a_str = '1';
    b_str = '0';
    c_str = '-tan(30)';
    d_str = '1';
    tx1 = 0;
    ty1 = 0;
    tx2 = 0;
    ty2 = 0;
elseif strcmp( transform_str, '90 deg clock rotation about (0,0)' )
    a = 0;
    b = 1;
    c = -1;
    d = 0;
    a_str = '0';
    b_str = '1';
    c_str = '-1';
    d_str = '0';
    tx1 = 0;
    ty1 = 0;
    tx2 = 0;
    ty2 = 0;
elseif strcmp( transform_str, 'Reflection in x axis' )
    a = 1;
    b = 0;
    c = 0;
    d = -1;
    a_str = '1';
    b_str = '0';
    c_str = '0';
    d_str = '-1';
    tx1 = 0;
    ty1 = 0;
    tx2 = 0;
    ty2 = 0;
elseif strcmp( transform_str, 'Reflection in line y=2' )
    a = 1;
    b = 0;
    c = 0;
    d = -1;
    a_str = '1';
    b_str = '0';
    c_str = '0';
    d_str = '-1';
    tx1 = 0;
    ty1 = 2;
    tx2 = 0;
    ty2 = 2;
elseif strcmp( transform_str, '42 deg clock rotation about (0,0)' )
    a = cos(pi*42/180);
    b = sin(pi*42/180);
    c = -sin(pi*42/180);
    d = cos(pi*42/180);
    a_str = 'cos(42)';
    b_str = 'sin(42)';
    c_str = '-sin(42)';
    d_str = 'cos(42)';
    tx1 = 0;
    ty1 = 0;
    tx2 = 0;
    ty2 = 0;
elseif strcmp( transform_str, '42 deg clock rotation about object centre' )
    a = cos(pi*42/180);
    b = sin(pi*42/180);
    c = -sin(pi*42/180);
    d = cos(pi*42/180);
    a_str = 'cos(42)';
    b_str = 'sin(42)';
    c_str = '-sin(42)';
    d_str = 'cos(42)';
    tx1 = mean(x);
    ty1 = mean(y);
    tx2 = mean(x);
    ty2 = mean(y);
elseif strcmp( transform_str, 'theta deg clock rotation about (0,0)' )
    a = cos(pi*theta/180);
    b = sin(pi*theta/180);
    c = -sin(pi*theta/180);
    d = cos(pi*theta/180);
    a_str = 'cos(theta)';
    b_str = 'sin(theta)';
    c_str = '-sin(theta)';
    d_str = 'cos(theta)';
    tx1 = 0;
    ty1 = 0;
    tx2 = 0;
    ty2 = 0;
elseif strcmp( transform_str, 'theta deg clock rotation about object centre' )
    a = cos(pi*theta/180);
    b = sin(pi*theta/180);
    c = -sin(pi*theta/180);
    d = cos(pi*theta/180);
    a_str = 'cos(theta)';
    b_str = 'sin(theta)';
    c_str = '-sin(theta)';
    d_str = 'cos(theta)';
    tx1 = mean(x);
    ty1 = mean(y);
    tx2 = mean(x);
    ty2 = mean(y);
elseif strcmp( transform_str, 'Reflection in line y = x*tan(theta)' )
    a = cos(2*pi*theta/180);
    b = sin(2*pi*theta/180);
    c = sin(2*pi*theta/180);
    d = -cos(2*pi*theta/180);
    a_str = 'cos(2*theta)';
    b_str = 'sin(2*theta)';
    c_str = 'sin(2*theta)';
    d_str = '-cos(2*theta)';
    tx1 = 0;
    ty1 = 0;
    tx2 = 0;
    ty2 = 0;
elseif strcmp( transform_str, 'Stretch scale factor k from invariant line y = -x*cot(theta)' )
    a = k*cos(pi*theta/180)^2 + sin(pi*theta/180)^2;
    b = 0.5*(k-1)*sin(2*pi*theta/180);
    c = 0.5*(k-1)*sin(2*pi*theta/180);
    d = k*sin(pi*theta/180)^2 + cos(pi*theta/180)^2;
    a_str = 'k*cos(theta)^2 + sin(theta)^2';
    b_str = '0.5*(k-1)*sin(2*theta)';
    c_str = '0.5*(k-1)*sin(2*theta)';
    d_str = 'k*sin(theta)^2 + cos(theta)^2';
    tx1 = 0;
    ty1 = 0;
    tx2 = 0;
    ty2 = 0;
elseif strcmp( transform_str, 'Shear, factor k, invariant line y = x*tan(theta)' )
    a = 1 - 0.5*k*sin(2*theta*pi/180);
    b = k*cos(theta*pi/180)^2;
    c = -k*sin(pi*theta/180)^2;
    d = 1 + 0.5*k*sin(2*theta*pi/180);
    a_str = '1 - 0.5*k*sin(2*theta)';
    b_str = 'k*cos(theta)^2';
    c_str = '-k*sin(theta)^2';
    d_str = '1 + 0.5*k*sin(theta)';
    tx1 = 0;
    ty1 = 0;
    tx2 = 0;
    ty2 = 0;
end

%End of code