%mtrans
% Function which transforms the (x,y) coordinates of a 2D object.
%
% [x,y] = mtrans( x, y, T, t1, t2 )
%
% x is a row vector of x coordinates
% y is a row vector of y coordinates
% T is a 2 x 2 transformation matrix
% t1 is a 2 x 1 translation vector
% t2 is a 2 x 1 translation vector
%
% Transformation equation is [x;y] = T * ( [x - t1(1) ; y - t1(2) ] ) + t2

function [x,y] = mtrans( x, y, T, t1, t2 )

%Translate original coordinates and form a coordinate marix r
R = [x;y] - repmat( t1, [1,length(x)] );

%Apply matrix transformation and define outputs
R = T * R + repmat( t2, [1,length(x)] );
x = R(1,:);
y = R(2,:);

%End of code