%polygon
% Function which returns the (x,y) coordinates of the vertices of a regular
% polygon of N sides and 'radius' R.

function [x,y] = polygon(N,R)

%Divide up 2*pi radians in N steps. (i.e. last step returns to zero or
%2*pi radians).
a = 0 : 2*pi/N : 2*pi - 2*pi/N;

%Construct (x,y) vertices. Note a square is a special case  - vertices
%point NE, SE, SW and NW
if N==4
    a = a+pi/4;
end
x = R*sin(a);
y = R*cos(a);

%%

function polygon_test

%Number of vertices
N = 3;

%Radius
R = 2;

%Compute polygon vertices
[x,y] = polygon(N,R);

%Plot as a coloured patch
figure('color',[1 1 1])
patch(x,y,'r');
axis equal
xlabel('x')
ylabel('y')
title( [ 'Polygon of ',num2str(N),' vertices, radius = ',num2str(R) ] );
xlim( [-1.5*R,1.5*R] )
ylim( [-1.5*R,1.5*R] )

%End of code