%star
% Function which returns the (x,y) coordinates an N pointed regular star

function [x,y] = star(N,R,F)

%Divide up 2*pi radians in 2*N steps. (i.e. last step returns to zero or
%2*pi radians).
N = 2*N;
a = 0 : 2*pi/N : 2*pi - 2*pi/N;

%Construct star radii vector with alternate values of 0.5*R and R
k=0;
r = R*ones(1,N);
for n=1:N
    if k==1
        r(n)=r(n)/F;
        k=0;
    else
        k=1;
    end      
end

%Construct (x,y) vertices.
x = r.*sin(a);
y = r.*cos(a);

%%

function star_test

%Number of vertices
N = 2;

%Radius
R = 2;

%Star stretch factor
F = 3;

%Compute polygon vertices
[x,y] = star(N,R,F);

%Plot as a coloured patch
figure('color',[1 1 1])
patch(x,y,'r');
axis equal
xlabel('x')
ylabel('y')
title( [ 'Star of ',num2str(N),' vertices, radius = ',num2str(R) ] );
xlim( [-1.5*R,1.5*R] )
ylim( [-1.5*R,1.5*R] )

%End of code