%mtrans2D
% GUI front end for Matrix Transformer 2D

function varargout = mtrans2D(varargin)

%% Begin initialization code - DO NOT EDIT %%
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
    'gui_Singleton',  gui_Singleton, ...
    'gui_OpeningFcn', @mtrans2D_OpeningFcn, ...
    'gui_OutputFcn',  @mtrans2D_OutputFcn, ...
    'gui_LayoutFcn',  [] , ...
    'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end

%%


%% GUI opening function %%
function mtrans2D_OpeningFcn(hObject, eventdata, handles, varargin)

% Choose default command line output for mtrans2D
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

%Add 'functions' directory to MATLAB path
addpath('functions','-begin');

%Center figure
set(0,'units','pixels');
set( handles.FIGUREmtrans2D, 'position', figcenter( 'FIGUREmtrans2D' ) );

% Load previous GUI settings, or default
if exist('last_mtrans2D_settings.mat','file')
    load('last_mtrans2D_settings.mat');
else
    M = mtrans2D_defaults;
end

%Set version string
set( handles.TEXTversion,'string', mtrans2D_version );

%Set new object to be ' ' to avoid confusion
set( handles.POPUPMENUnewobject,'value',1 );

%Set up axes ...

%Main canvas
axes(handles.AXEScanvas);
axis equal;
hold on;
grid on;

%Basis vectors before matrix transformation
axes(handles.AXESuvbefore);
axis equal;
draw_basis_vectors( handles.AXESuvbefore, [1,0], [0,1] );

%Basis vectors after matrix transformation
axes(handles.AXESuvafter);
axis equal;
hold on;
xlabel('x'); ylabel('y');

%Current object
axes(handles.AXESobject);
axis equal;
hold on;
xlabel('x'); ylabel('y');
grid on;

%Store mtrans2D settings in handles array, to enable GUI callback
%functions to see this data
handles.M = M;

%Update GUI
handles = mtrans2D_update_gui(handles);

%Update handles structure
guidata(hObject, handles);

%Update mtrans2D
mtrans2D_update

%%

%% GUI output function %%
function varargout = mtrans2D_OutputFcn(hObject, eventdata, handles)
varargout{1} = handles.output;

%%

%% Save figure and .png %%
function PUSHsavefig_Callback(hObject, eventdata, handles)

axes(handles.AXEScanvas);
cax = caxis;
cmap = colormap;
norm_position = [0.13 0.11 0.675 0.815];
name = ['mtrans2D_image ',strrep(datestr(now),':','-')];
savepics = 2;
picsave_method = 1;
[new_fig,new_ax] =...
    plot_in_new_window(handles.FIGUREmtrans2D,...
    handles.AXEScanvas,...
    [],cax,cmap,...
    norm_position,name,savepics,picsave_method);

%%

%% Load file %%
function PUSHloadfile_Callback(hObject, eventdata, handles)

%Return path to valid .mat file obtained via Explorer navigation by user
%which contains spherium setup information.
[filename, pathname, filterindex] = uigetfile('*.mat', 'Choose a .mat file containing mtrans2D settings');

if filename ~=0
    %Load .mat file and update handles array of GUI with information contained
    %within the .mat file. If this doesn't work flag up an error dialogue box
    old_M = handles.M;
    try
        load( [pathname, '\', filename] );
        
        %Store settings in handles array, to enable GUI callback
        %functions to see this data
        handles = guidata(hObject);
        handles.M = M;
        
        %Update GUI
        handles = mtrans2D_update_gui(handles);
        guidata(hObject,handles);
        mtrans2D_update;
    catch
        errordlg('.mat file selected does not contain the correct inputs for mtrans2D','mtrans2D error!')
        %Update GUI with original settings
        handles.M = old_M;
        handles = mtrans2D_update_gui(handles);
        guidata(hObject,handles);
        mtrans2D_update;
        return
    end
end

%%

%% Save file %%
function PUSHsavefile_Callback(hObject, eventdata, handles)

%Return path to valid .mat file obtained via Explorer navigation by user
%which will contains mtrans2D setup information.
[filename, pathname, filterindex] = uiputfile('*.mat', 'Save mtrans2D GUI settings in a .mat file');

%Save .mat file containing GUI settings
if ~isequal(filename,0) && ~isequal(pathname,0)
    handles = guidata(hObject);
    M = handles.M;
    save( [pathname,'\',filename], 'M' );
end

%%

%% Select new object popupmenu %%
function POPUPMENUnewobject_Callback(hObject, eventdata, handles)

%Get data from GUI
handles = guidata(hObject);

%Find current number of objects
num_objects = length(handles.M.object);

%Create new object
name = handles.M.new_objects{ get(handles.POPUPMENUnewobject,'value') };
if ~strcmp( name, ' ')
    [x,y] = create_shape( name );
    handles.M.object(num_objects+1).name = [name,' ',num2str(num_objects+1)];
    handles.M.object(num_objects+1).colour = set_object_colour(num_objects+1);
    handles.M.object(num_objects+1).centre_x = mean(x);
    handles.M.object(num_objects+1).centre_y = mean(y);
    handles.M.object(num_objects+1).aspect = 1;
    handles.M.object(num_objects+1).rot_deg = 0;
    handles.M.object(num_objects+1).scale_factor = 1;
    handles.M.object(num_objects+1).x = x;
    handles.M.object(num_objects+1).y = y;
    handles.M.object_list = [handles.M.object_list,...
        handles.M.object(num_objects+1).name];
    
    %Set current object number to be the last object created
    handles.M.current_object_number = num_objects+1;
    
    %Update GUI
    handles = mtrans2D_update_gui(handles);
    guidata(hObject, handles);
    mtrans2D_update;
end

%%

%% Object list popupmenu %%
function POPUPMENUobject_Callback(hObject, eventdata, handles)

%Get data from GUI
handles = guidata(hObject);

%Set current object number to be the object selected in the menu
handles.M.current_object_number = get( handles.POPUPMENUobject,'value' );

%Update GUI
handles = mtrans2D_update_gui(handles);
guidata(hObject, handles);
mtrans2D_update;

%%

%% Delete current object pushbutton %%
function PUSHdeleteobject_Callback(hObject, eventdata, handles)

%Get data from GUI
handles = guidata(hObject);

%Find current number of objects
num_objects = length(handles.M.object);

%Store old object structure
old_objects = handles.M.object;

%Create an empty object structure
handles.M.object = [];
handles.M.object_list = {};
handles.M.current_object_number = 0;

%Reform list of objects without current object n
if num_objects ~= 1
    
    %Determine object number to be deleted
    n = get( handles.POPUPMENUobject,'value' );
    
    %Form new structure, sans object n
    k=1;
    for m=1:num_objects
        if m~=n
            handles.M.object(k).colour = old_objects(m).colour;
            handles.M.object(k).centre_x = old_objects(m).centre_x;
            handles.M.object(k).centre_y = old_objects(m).centre_y;
            handles.M.object(k).aspect = old_objects(m).aspect;
            handles.M.object(k).rot_deg = old_objects(m).rot_deg;
            handles.M.object(k).scale_factor = old_objects(m).scale_factor;
            handles.M.object(k).name = old_objects(m).name;
            handles.M.object_list = [ handles.M.object_list, old_objects(m).name ];
            handles.M.object(k).x = old_objects(m).x;
            handles.M.object(k).y = old_objects(m).y;
            k=k+1;
        end
    end
    handles.M.current_object_number = 1;
end

%Update GUI
handles = mtrans2D_update_gui(handles);
guidata(gcf, handles);
mtrans2D_update;

%%

%% Transform curent object pushbutton %%
function PUSHtransformobject_Callback(hObject, eventdata, handles)

%Get data from GUI
handles = guidata(hObject);

%Find current number of objects
num_objects = length(handles.M.object);
if num_objects~=0
    %Get relevant parameters of current object
    n = handles.M.current_object_number;
    name = handles.M.object(n).name;
    x = handles.M.object(n).x;
    y = handles.M.object(n).y;
    
    %Get parameters of transformation equation
    a = handles.M.transform_a;
    b = handles.M.transform_b;
    c = handles.M.transform_c;
    d = handles.M.transform_d;
    p = handles.M.transform_power;
    t1x = handles.M.transform_tx1;
    t1y = handles.M.transform_ty1;
    t2x = handles.M.transform_tx2;
    t2y = handles.M.transform_ty2;
    
    %Define transformation matrix
    T = [a,b;c,d]^p;
    T = real(T);
    
    %Create new objects (s) following the defined transformation
    for n=1:handles.M.iterations
        
        %Apply transformation
        [x,y] = mtrans( x, y, T, [t1x;t1y], [t2x;t2y] );
        handles.M.object(num_objects+n).name = [name,' ',num2str(num_objects+n)];
        handles.M.object(num_objects+n).colour = set_object_colour(num_objects+1);
        handles.M.object(num_objects+n).centre_x = mean(x);
        handles.M.object(num_objects+n).centre_y = mean(y);
        handles.M.object(num_objects+n).aspect = 1;
        handles.M.object(num_objects+n).rot_deg = 0;
        handles.M.object(num_objects+n).scale_factor = 1;
        handles.M.object(num_objects+n).x = x;
        handles.M.object(num_objects+n).y = y;
        handles.M.object_list = [handles.M.object_list,...
            handles.M.object(num_objects+n).name];
    end
    
    %Set current object number to be the last object created
    handles.M.current_object_number = num_objects+n;
    
    %Update GUI
    handles = mtrans2D_update_gui(handles);
    guidata(gcf, handles);
    mtrans2D_update;
end

%%

%% Object centre (x) %%
function EDITobjx_Callback(hObject, eventdata, handles)

%Get data from gui
handles = guidata(hObject);
num_objects = length(handles.M.object);
if num_objects~=0
    n = handles.M.current_object_number;
    x = handles.M.object(n).x;
    y = handles.M.object(n).y;
    cx_new = str2num( get(handles.EDITobjx,'string') );
    cx_old = handles.M.object(n).centre_x;
    cy_new = str2num( get(handles.EDITobjy,'string') );
    cy_old = handles.M.object(n).centre_y;
    
    %Update object properties
    handles.M.object(n).centre_x = cx_new;
    handles.M.object(n).centre_y = cy_new;
    [handles.M.object(n).x,handles.M.object(n).y] = mtrans( x, y, [1,0;0,1],...
        [ cx_old; cy_old ],...
        [ cx_new ; cy_new ] );
    
    %Update GUI
    guidata(gcf, handles);
    mtrans2D_update;
end

%%

%% Object centre (y) %%
function EDITobjy_Callback(hObject, eventdata, handles)

%Get data from gui
handles = guidata(hObject);
num_objects = length(handles.M.object);
if num_objects~=0
    n = handles.M.current_object_number;
    x = handles.M.object(n).x;
    y = handles.M.object(n).y;
    cx_new = str2num( get(handles.EDITobjx,'string') );
    cx_old = handles.M.object(n).centre_x;
    cy_new = str2num( get(handles.EDITobjy,'string') );
    cy_old = handles.M.object(n).centre_y;
    
    %Update object properties
    handles.M.object(n).centre_x = cx_new;
    handles.M.object(n).centre_y = cy_new;
    [handles.M.object(n).x,handles.M.object(n).y] = mtrans( x, y, [1,0;0,1],...
        [ cx_old; cy_old ],...
        [ cx_new ; cy_new ] );
    
    %Update GUI
    guidata(gcf, handles);
    mtrans2D_update;
end

%%

%% Object aspect ratio (y/x) %%
function EDITobjaspect_Callback(hObject, eventdata, handles)

%Get data from gui
handles = guidata(hObject);
num_objects = length(handles.M.object);
if num_objects~=0
    n = handles.M.current_object_number;
    x = handles.M.object(n).x;
    y = handles.M.object(n).y;
    cx = handles.M.object(n).centre_x;
    cy = handles.M.object(n).centre_y;
    aspect_old = handles.M.object(n).aspect;
    aspect = str2num( get(handles.EDITobjaspect,'string') );
    a= (pi/180)*handles.M.object(n).rot_deg;
    handles.M.object(n).aspect = aspect;
    F = aspect/aspect_old;
    
    %Update object properties. Note aspect change is a stretch in the rotated
    %direction. Hence rotate back to original position, stretch in y, rotate
    %back
    a=-a;
    [x,y] = mtrans( x, y,...
        [cos(a), sin(a) ; -sin(a), cos(a) ],...
        [ cx; cy ],...
        [ cx; cy ] );
    [x,y] = mtrans( x, y,...
        [1, 0 ; 0, F ],...
        [ cx; cy ],...
        [ cx; cy ] );
    a=-a;
    [handles.M.object(n).x,handles.M.object(n).y] = mtrans( x, y,...
        [cos(a), sin(a) ; -sin(a), cos(a) ],...
        [ cx; cy ],...
        [ cx; cy ] );
    
    %Update GUI
    guidata(gcf, handles);
    mtrans2D_update;
end

%%

%% Object rotation clockwise from Up %%
function EDITobjrot_Callback(hObject, eventdata, handles)

%Get data from gui
handles = guidata(hObject);
num_objects = length(handles.M.object);
if num_objects~=0
    n = handles.M.current_object_number;
    x = handles.M.object(n).x;
    y = handles.M.object(n).y;
    cx = str2num( get(handles.EDITobjx,'string') );
    cy = str2num( get(handles.EDITobjy,'string') );
    a_old = (pi/180)*handles.M.object(n).rot_deg;
    a = (pi/180)*str2num( get(handles.EDITobjrot,'string') );
    
    %Update object properties
    handles.M.object(n).rot_deg = 180*a/pi;
    a = a-a_old;
    [handles.M.object(n).x,handles.M.object(n).y] = mtrans( x, y,...
        [cos(a), sin(a) ; -sin(a), cos(a) ],...
        [ cx; cy ],...
        [ cx; cy ] );
    
    %Update GUI
    guidata(gcf, handles);
    mtrans2D_update;
end

%%

%% Object enlargement from object centre %%
function EDITscalefactor_Callback(hObject, eventdata, handles)

%Get data from gui
handles = guidata(hObject);
num_objects = length(handles.M.object);
if num_objects~=0
    n = handles.M.current_object_number;
    x = handles.M.object(n).x;
    y = handles.M.object(n).y;
    cx = str2num( get(handles.EDITobjx,'string') );
    cy = str2num( get(handles.EDITobjy,'string') );
    sf_old = handles.M.object(n).scale_factor;
    s = str2num( get(handles.EDITscalefactor,'string') );
    
    %Update object properties
    handles.M.object(n).scale_factor = s;
    sf = s/sf_old;
    [handles.M.object(n).x,handles.M.object(n).y] = mtrans( x, y,...
        [sf, 0 ; 0, sf ],...
        [ cx; cy ],...
        [ cx; cy ] );
    
    %Update GUI
    guidata(gcf, handles);
    mtrans2D_update;
end

%%

%% Transformation matrix a %%
function EDITa_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
eval(['handles.M.transform_a =',trig_str_deg2rad( get( handles.EDITa,'string' ) ),';'] );
if handles.M.show_basis_vectors==1;
    update_basis_vectors(handles);
end
guidata(gcf, handles);

%%

%% Transformation matrix b %%
function EDITb_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
eval(['handles.M.transform_b =',trig_str_deg2rad( get( handles.EDITb,'string' ) ),';'] );
if handles.M.show_basis_vectors==1;
    update_basis_vectors(handles);
end
guidata(gcf, handles);

%%

%% Transformation matrix c %%
function EDITc_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
eval(['handles.M.transform_c =',trig_str_deg2rad( get( handles.EDITc,'string' ) ),';'] );
if handles.M.show_basis_vectors==1;
    update_basis_vectors(handles);
end
guidata(gcf, handles);

%%

%% Transformation matrix d %%
function EDITd_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
eval(['handles.M.transform_d =',trig_str_deg2rad( get( handles.EDITd,'string' ) ),';'] );
if handles.M.show_basis_vectors==1;
    update_basis_vectors(handles);
end
guidata(gcf, handles);

%%

%% Transformation matrix power %%
function EDITpower_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.transform_power = str2num( get( handles.EDITpower,'string' ));
if handles.M.show_basis_vectors==1;
    update_basis_vectors(handles);
end
guidata(gcf, handles);

%%

%% Transformation equation x translation 1 %%
function EDITtx1_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.transform_tx1 = str2num( get( handles.EDITtx1,'string' ));
guidata(gcf, handles);

%%

%% Transformation equation y translation 1 %%
function EDITty1_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.transform_ty1 = str2num( get( handles.EDITty1,'string' ));
guidata(gcf, handles);

%%

%% Transformation equation x translation 2 %%
function EDITtx2_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.transform_tx2 = str2num( get( handles.EDITtx2,'string' ));
guidata(gcf, handles);

%%

%% Transformation equation y translation 2 %%
function EDITty2_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.transform_ty2 = str2num( get( handles.EDITty2,'string' ));
guidata(gcf, handles);

%%

%% Transformation iterations %%
function EDITiterations_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.iterations = str2num( get( handles.EDITiterations,'string' ));
guidata(gcf, handles);

%%

%% Label vertices toggle %%
function CHECKlabelvertices_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.label_vertices = get( handles.CHECKlabelvertices,'value' );
guidata(gcf, handles);
mtrans2D_update

%%

%% Set transformation matrix elements based upon defaults %%
function POPUPMENUsetmatrix_Callback(hObject, eventdata, handles)

%Get data from GUI
handles = guidata(hObject);
handles.M.transformation =...
    handles.M.transformations{ get( handles.POPUPMENUsetmatrix,'value' ) };

%Get data relating to the current object
num_objects = length(handles.M.object);
if num_objects~=0
    n = handles.M.current_object_number;
    x = handles.M.object(n).x;
    y = handles.M.object(n).y;
else
    x = 0;
    y = 0;
end

%Obtain parameters relating to the selected transformation
[ handles.M.transform_a,...
    handles.M.transform_b,...
    handles.M.transform_c,...
    handles.M.transform_d,...
    a_str,b_str,c_str,d_str,...
    handles.M.transform_tx1,...
    handles.M.transform_ty1,...
    handles.M.transform_tx2,...
    handles.M.transform_ty2] =...
    matrix_transform( handles.M.transformation, x, y, handles.M.k,handles.M.theta );

%Update GUI
set( handles.EDITa,'string', a_str );
set( handles.EDITb,'string', b_str );
set( handles.EDITc,'string', c_str );
set( handles.EDITd,'string', d_str );
set( handles.EDITtx1,'string', num2str(handles.M.transform_tx1) );
set( handles.EDITty1,'string', num2str(handles.M.transform_ty1)  );
set( handles.EDITtx2,'string', num2str(handles.M.transform_tx2)  );
set( handles.EDITty2,'string', num2str(handles.M.transform_ty2)  );
guidata(gcf, handles);
mtrans2D_update

%%

%% Set y maximum of canvass %%
function EDITymax_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.ymax = str2num( get(handles.EDITymax,'string') );
guidata(gcf, handles);
mtrans2D_update

%%

%% Set y minimum of canvass %%
function EDITymin_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.ymin = str2num( get(handles.EDITymin,'string') );
guidata(gcf, handles);
mtrans2D_update

%%

%% Set ytick interval of canvass %%
function EDITytick_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.ytick = str2num( get(handles.EDITytick,'string') );
guidata(gcf, handles);
mtrans2D_update

%%

%% Set x maximum of canvass %%
function EDITxmax_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.xmax = str2num( get(handles.EDITxmax,'string') );
guidata(gcf, handles);
mtrans2D_update

%%

%% Set x minimum of canvass %%
function EDITxmin_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.xmin = str2num( get(handles.EDITxmin,'string') );
guidata(gcf, handles);
mtrans2D_update

%%

%% Set xtick interval of canvass %%
function EDITxtick_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.xtick = str2num( get(handles.EDITxtick,'string') );
guidata(gcf, handles);
mtrans2D_update

%%

%% Auto axis scale toggle %%
function CHECKautoaxisscale_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.auto_axis_scale = get(handles.CHECKautoaxisscale,'value');
guidata(gcf, handles);
mtrans2D_update

%%

%% k parameter %%
function EDITk_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.k = str2num( get(handles.EDITk,'string') );
guidata(gcf, handles);
mtrans2D_update

%%

%% theta parameter %%
function EDITtheta_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.theta = str2num( get(handles.EDITtheta,'string') );
guidata(gcf, handles);
mtrans2D_update

%%

%% About (0,0) radio button %%
% This toggles the extra translation components, but makes the GUI slightly
% more complicated. For students new to matrix transformations, toggling
% this button will hide the extra parameters, and set the translation
% vectors to zero.
function RADIOaboutorigin_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.about_origin = get(handles.RADIOaboutorigin,'value');
guidata(gcf, handles);
mtrans2D_update

%%

%% Show or hide basis vectors radiobutton %%
function RADIOshowbasisvectors_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
handles.M.show_basis_vectors = get(handles.RADIOshowbasisvectors,'value');
guidata(gcf, handles);
mtrans2D_update

%%

%GUI update function
function mtrans2D_update

%Update handles structure
handles = guidata(gcf);

%Depending on whether about_origin flag has been set, hide or show the
%translation parts of the matrix equation
if handles.M.about_origin == 1
    %Hide translation boxes
    set( handles.TEXTbracketL,'visible','off' );
    set( handles.TEXTbracketR,'visible','off' );
    set( handles.TEXTminus,'visible','off' );
    set( handles.TEXTtx1,'visible','off' );
    set( handles.TEXTtx2,'visible','off' );
    set( handles.TEXTtx1bracket,'visible','off' );
    set( handles.TEXTtx2bracket,'visible','off' );
    set( handles.EDITtx1,'visible','off','enable','off');
    set( handles.EDITty1,'visible','off','enable','off' );
    set( handles.EDITtx2,'visible','off','enable','off' );
    set( handles.EDITty2,'visible','off','enable','off' );
    set( handles.TEXTplus,'visible','off' );
    
    %Set translations to (0,0)
    handles.M.transform_tx1 = 0;
    handles.M.transform_ty1 = 0;
    handles.M.transform_tx2 = 0;
    handles.M.transform_ty2 = 0;
    set( handles.EDITtx1,'string','0');
    set( handles.EDITty1,'string','0');
    set( handles.EDITtx2,'string','0');
    set( handles.EDITty2,'string','0');
       
else
    %Unhide translation boxes
    set( handles.TEXTbracketL,'visible','on' );
    set( handles.TEXTbracketR,'visible','on' );
    set( handles.TEXTminus,'visible','on' );
    set( handles.TEXTtx1,'visible','on' );
    set( handles.TEXTtx2,'visible','on' );
    set( handles.TEXTtx1bracket,'visible','on' );
    set( handles.TEXTtx2bracket,'visible','on' );
    set( handles.EDITtx1,'visible','on','enable','on' );
    set( handles.EDITty1,'visible','on','enable','on' );
    set( handles.EDITtx2,'visible','on','enable','on' );
    set( handles.EDITty2,'visible','on','enable','on' );
    set( handles.TEXTplus,'visible','on' );   
end

%Show or hide basis vectors
if handles.M.show_basis_vectors == 1
    %Show basis vector before and after plot
    set( handles.TEXTbasisbefore,'visible','on' );
    set( handles.TEXTbasisafter,'visible','on' );
    set( handles.AXESuvbefore,'visible','on' );
    set( handles.AXESuvafter,'visible','on' );
    
   %Update 'Before & After' basis vector plots
    update_basis_vectors(handles);
else
    %Hide basis vector before and after plot
    set( handles.TEXTbasisbefore,'visible','off' );
    set( handles.TEXTbasisafter,'visible','off' );
    set( handles.AXESuvbefore,'visible','off' );
    set( handles.AXESuvafter,'visible','off' );   
    axes(handles.AXESuvbefore); cla;
    axes(handles.AXESuvafter); cla;  
end

%Determine number of objects - there might be none!
num_objects = length( handles.M.object );

%Draw current object in AXESobject axes
axes(handles.AXESobject);
cla;
if num_objects~=0
    n = handles.M.current_object_number;
    patch( handles.M.object(n).x,...
        handles.M.object(n).y,...
        handles.M.object(n).colour,'edgecolor','none'  );
    
    %Label vertices if option selected
    if handles.M.label_vertices==1
        for m=1:length(handles.M.object(n).x)
            text( handles.M.object(n).x(m),...
                handles.M.object(n).y(m),...
                num2str(m),'fontsize', 14,'edgecolor',[ 0 0 0 ] );
        end
    end
end
axis equal;
alpha(0.8);

%Draw all objects in AXEScanvas
axes(handles.AXEScanvas);
cla;
hold on;

%Draw grid

%Draw objects
if num_objects~=0
    for n=1:num_objects
        patch( handles.M.object(n).x,...
            handles.M.object(n).y,...
            handles.M.object(n).colour,'edgecolor','none' );
        
        %Label vertices if option selected
        if handles.M.label_vertices==1
            for m=1:length(handles.M.object(n).x)
                text( handles.M.object(n).x(m),...
                    handles.M.object(n).y(m),...
                    num2str(m),'fontsize', 14,'edgecolor',[ 0 0 0 ]  );
            end
        end
    end
end
axis equal;
alpha(0.8);

%Set axis limits
if handles.M.auto_axis_scale == 0
    %Fixed axis scale
    xlim( [handles.M.xmin,handles.M.xmax] );
    ylim( [handles.M.ymin,handles.M.ymax] );
else
    %Update axis limits based upon recent 'scale to fit' computation
    axis tight
    xlimit = get(gca,'xlim');
    ylimit = get(gca,'ylim');
    handles.M.xmin = xlimit(1);
    handles.M.xmax = xlimit(2);
    handles.M.ymin = ylimit(1);
    handles.M.ymax = ylimit(2);
    p = handles.M.num_display_precision;
    set( handles.EDITymax,'string', num2str(handles.M.ymax,p) );
    set( handles.EDITymin,'string', num2str(handles.M.ymin,p) );
    set( handles.EDITxmax,'string', num2str(handles.M.xmax,p) );
    set( handles.EDITxmin,'string', num2str(handles.M.xmin,p) );
end

%Set axis tick marks
set(handles.AXEScanvas,'xtick',roundn( handles.M.xmin : handles.M.xtick : handles.M.xmax,1),...
    'ytick',roundn( handles.M.ymin : handles.M.ytick : handles.M.ymax, 1) );

%Plot x,y axis
xlimit = get(gca,'xlim');
ylimit = get(gca,'ylim');
axis manual
plot([0,0],ylimit,'k','linewidth',1);
plot(xlimit,[0,0],'k','linewidth',1);

%Set x and y labels to be next to and at the end of the axis
xlabel(' ')
ylabel(' ')
text( -1, handles.M.ymax, 0, 'y', 'fontsize', 14 );
text( handles.M.xmax + 0.5, 0 , 0,  'x', 'fontsize', 14 );
plot( handles.M.xmax, 0, 'k>','markerfacecolor','k' );
plot( 0,handles.M.ymax, 'k^','markerfacecolor','k'  );

%Turn on box
box on

%Update handles structure
guidata(gcf, handles);

%%

%% Update basis vector 'After' plot based upon modified transformation matrix %%
function update_basis_vectors(handles)

M = [handles.M.transform_a,handles.M.transform_b ;...
    handles.M.transform_c, handles.M.transform_d]^handles.M.transform_power ;
M = real(M);
draw_basis_vectors( handles.AXESuvafter, [M(1,1),M(2,1)], [M(1,2),M(2,2)] );
draw_basis_vectors( handles.AXESuvbefore, [1,0], [0,1] );

%%

%% Close function %%
function mtrans2D_close(hObject, eventdata, handles)

%Saves settings (in structure handles.M) to a .mat file and closes GUI
M = handles.M;
save last_mtrans2D_settings M
closereq;

%Remove 'functions' directory from MATLAB path
rmpath('functions')

%%

%% Set object colour %%
function rgb = set_object_colour(n)
if n==1
    rgb = [1,0,0];
elseif n==2
    rgb = [0,0,1];
elseif n==3
    rgb = [0,1,0];
elseif n==4
    rgb = [1,0,1];
elseif n==4
    rgb = [1,1,0];
else
    rgb=rand(1,3);
end

%%

%Round to n decimal places
function x = roundn(x,n)
x = x*10^n;
x = round(x);
x = x*10^-n;

%%

%End of code